@@ -20,6 +20,7 @@ import six
 from six.moves import configparser
 from six.moves import cStringIO as StringIO
 import subprocess
+import sys
 import tempfile
 import time
 import yaml
@@ -95,7 +96,7 @@ class AnsibleAction(actions.Action):
         self.hosts = self._kwargs_for_run.pop('hosts', None)
         self.module = self._kwargs_for_run.pop('module', None)
         self.module_args = self._kwargs_for_run.pop('module_args', None)
-        if self.module_args:
+        if self.module_args and isinstance(self.module_args, dict):
             self.module_args = json.dumps(self.module_args)
         self.limit_hosts = self._kwargs_for_run.pop('limit_hosts', None)
         self.remote_user = self._kwargs_for_run.pop('remote_user', None)
@@ -434,12 +435,16 @@ class AnsiblePlaybookAction(base.TripleOAction):
             queue.post(self.format_message(message_part))
 
     def run(self, context):
+
+        python_version = sys.version_info.major
+        ansible_playbook_cmd = "ansible-playbook-{}".format(python_version)
+
         if 0 < self.verbosity < 6:
             verbosity_option = '-' + ('v' * self.verbosity)
-            command = ['ansible-playbook', verbosity_option,
+            command = [ansible_playbook_cmd, verbosity_option,
                        self.playbook]
         else:
-            command = ['ansible-playbook', self.playbook]
+            command = [ansible_playbook_cmd, self.playbook]
 
         if self.limit_hosts:
             command.extend(['--limit', self.limit_hosts])
