@@ -233,33 +233,35 @@ class TestKollaImageBuilderTemplate(base.TestCase):
                 'openshift_heketi_namespace': 'docker.io/heketi',
                 'openshift_heketi_image': 'heketi',
                 'openshift_heketi_tag': 'latest',
+                'openshift_asb_namespace': 'docker.io/ansibleplaybookbundle',
+                'openshift_asb_tag': 'latest',
                 'openshift_cluster_monitoring_namespace': 'quay.io/coreos',
                 'openshift_cluster_monitoring_image':
                     'cluster-monitoring-operator',
                 'openshift_cluster_monitoring_tag': 'v0.1.1',
                 'openshift_configmap_reload_namespace': 'quay.io/coreos',
                 'openshift_configmap_reload_image': 'configmap-reload',
-                'openshift_configmap_reload_tag': 'latest',
+                'openshift_configmap_reload_tag': 'v0.0.1',
                 'openshift_prometheus_operator_namespace': 'quay.io/coreos',
                 'openshift_prometheus_operator_image': 'prometheus-operator',
-                'openshift_prometheus_operator_tag': 'latest',
+                'openshift_prometheus_operator_tag': 'v0.23.2',
                 'openshift_prometheus_config_reload_namespace':
                     'quay.io/coreos',
                 'openshift_prometheus_config_reload_image':
                     'prometheus-config-reloader',
-                'openshift_prometheus_config_reload_tag': 'v0.24.0',
-                'openshift_prometheus_tag': 'latest',
-                'openshift_prometheus_alertmanager_tag': 'latest',
-                'openshift_prometheus_node_exporter_tag': 'latest',
-                'openshift_oauth_proxy_tag': 'latest',
+                'openshift_prometheus_config_reload_tag': 'v0.23.2',
+                'openshift_prometheus_tag': 'v2.3.2',
+                'openshift_prometheus_alertmanager_tag': 'v0.15.2',
+                'openshift_prometheus_node_exporter_tag': 'v0.16.0',
+                'openshift_oauth_proxy_tag': 'v1.1.0',
                 'openshift_kube_rbac_proxy_namespace': 'quay.io/coreos',
                 'openshift_kube_rbac_proxy_image': 'kube-rbac-proxy',
                 'openshift_kube_rbac_proxy_tag': 'v0.3.1',
                 'openshift_kube_state_metrics_namespace': 'quay.io/coreos',
                 'openshift_kube_state_metrics_image': 'kube-state-metrics',
-                'openshift_kube_state_metrics_tag': 'latest',
+                'openshift_kube_state_metrics_tag': 'v1.3.1',
                 'openshift_grafana_namespace': 'docker.io/grafana',
-                'openshift_grafana_tag': 'latest',
+                'openshift_grafana_tag': '5.2.1',
             },
             builder.container_images_template_inputs()
         )
@@ -293,6 +295,9 @@ class TestKollaImageBuilderTemplate(base.TestCase):
                     'registry.access.redhat.com/rhgs3',
                 'openshift_heketi_image': 'rhgs-volmanager-rhel7',
                 'openshift_heketi_tag': 'heketi-tag',
+                'openshift_asb_namespace':
+                    'registry.access.redhat.com/openshift3',
+                'openshift_asb_tag': 'v3.11',
                 'openshift_cluster_monitoring_namespace':
                     'registry.access.redhat.com/openshift3',
                 'openshift_cluster_monitoring_image':
@@ -353,6 +358,9 @@ class TestKollaImageBuilderTemplate(base.TestCase):
                 openshift_heketi_namespace='registry.access.redhat.com/rhgs3',
                 openshift_heketi_image='rhgs-volmanager-rhel7',
                 openshift_heketi_tag='heketi-tag',
+                openshift_asb_namespace='registry.'
+                    'access.redhat.com/openshift3',
+                openshift_asb_tag='v3.11',
                 openshift_cluster_monitoring_namespace='registry.'
                     'access.redhat.com/openshift3',
                 openshift_cluster_monitoring_image='ose-'
